@@ -70,7 +70,7 @@ def get_accept_type(v):
 
 
 def post_process(rst):
-    if isinstance(rst, (dict, list)):
+    if isinstance(rst, (dict, list, tuple)):
         typ = get_accept_type(request.headers.get('Accept'))
         if typ == 'json':
             return Response(json.dumps(bytes2base64(rst)), mimetype='application/json')
@@ -153,6 +153,7 @@ def make_app(predictor_cls):
     parser.add_argument('--port', type=int, default=port, help='服务监听端口')
 
     app = Flask('model-serving')
+    app.config['JSON_AS_ASCII'] = False
 
     log.info('Openbayes Serving 正在启动...')
 
